TableLayer
==========

.. currentmodule:: pywwt.layers

.. autoclass:: TableLayer
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~TableLayer.alt_att
      ~TableLayer.alt_type
      ~TableLayer.alt_unit
      ~TableLayer.cmap
      ~TableLayer.cmap_att
      ~TableLayer.cmap_vmax
      ~TableLayer.cmap_vmin
      ~TableLayer.color
      ~TableLayer.coord_type
      ~TableLayer.far_side_visible
      ~TableLayer.lat_att
      ~TableLayer.lon_att
      ~TableLayer.lon_unit
      ~TableLayer.marker_scale
      ~TableLayer.marker_type
      ~TableLayer.opacity
      ~TableLayer.size_att
      ~TableLayer.size_scale
      ~TableLayer.size_vmax
      ~TableLayer.size_vmin
      ~TableLayer.time_att
      ~TableLayer.time_decay
      ~TableLayer.time_series
      ~TableLayer.x_att
      ~TableLayer.xyz_unit
      ~TableLayer.y_att
      ~TableLayer.z_att

   .. rubric:: Methods Summary

   .. autosummary::

      ~TableLayer.remove
      ~TableLayer.update_data

   .. rubric:: Attributes Documentation

   .. autoattribute:: alt_att
   .. autoattribute:: alt_type
   .. autoattribute:: alt_unit
   .. autoattribute:: cmap
   .. autoattribute:: cmap_att
   .. autoattribute:: cmap_vmax
   .. autoattribute:: cmap_vmin
   .. autoattribute:: color
   .. autoattribute:: coord_type
   .. autoattribute:: far_side_visible
   .. autoattribute:: lat_att
   .. autoattribute:: lon_att
   .. autoattribute:: lon_unit
   .. autoattribute:: marker_scale
   .. autoattribute:: marker_type
   .. autoattribute:: opacity
   .. autoattribute:: size_att
   .. autoattribute:: size_scale
   .. autoattribute:: size_vmax
   .. autoattribute:: size_vmin
   .. autoattribute:: time_att
   .. autoattribute:: time_decay
   .. autoattribute:: time_series
   .. autoattribute:: x_att
   .. autoattribute:: xyz_unit
   .. autoattribute:: y_att
   .. autoattribute:: z_att

   .. rubric:: Methods Documentation

   .. automethod:: remove
   .. automethod:: update_data
